==> 2.3.1.tar.gz: lib/buzz_booster.dart <==
import 'package:buzz_booster/buzz_booster_method_channel.dart';
import 'buzz_booster_platform_interface.dart';

class BuzzBooster {
  Function(String)? _customCampaignMoveButtonClickedCallback = null;
  set customCampaignMoveButtonClickedCallback(Function(String)? callback){
    _customCampaignMoveButtonClickedCallback = callback;
  }

  Function()? _optInMarketingCampaignMoveButtonClickedCallback = null;
  set optInMarketingCampaignMoveButtonClickedCallback(Function()? callback){
    _optInMarketingCampaignMoveButtonClickedCallback = callback;
  }

  Function(String, Map<String, dynamic>?)? _userEventChannel = null;
  set userEventChannel(Function(String, Map<String, dynamic>?)? userEventChannel){
    _userEventChannel = userEventChannel;
  }

  BuzzBooster() {
    BuzzBoosterPlatform.instance.eventStream.listen((event) {
      if (event.key == NativeEvent.customCampaignMoveButtonClicked) {
        _customCampaignMoveButtonClickedCallback?.call(event.value as String);
      } else if (event.key == NativeEvent.optInMarketingCampaignMoveButtonClicked) {
        _optInMarketingCampaignMoveButtonClickedCallback?.call();
      } else if (event.key == NativeEvent.userEventDidOccur) {
        _userEventChannel?.call(event.value["userEventName"], event.value["userEventValues"]);
      }
    });
  }

  Future<void> setUser(User? user, ) {
    return BuzzBoosterPlatform.instance.setUser(user, );
  }

  Future<void> init(
      {required String androidAppKey, required String iosAppKey}) {
    return BuzzBoosterPlatform.instance
        .init(androidAppKey: androidAppKey, iosAppKey: iosAppKey);
  }

  Future<void> startService() {
    return BuzzBoosterPlatform.instance.startService();
  }

  Future<void> sendEvent(
    String eventName,
    Map<String, String>? eventValues,
  ) {
    return BuzzBoosterPlatform.instance.sendEvent(
      eventName,
      eventValues,
    );
  }

  Future<void> showInAppMessage() {
    return BuzzBoosterPlatform.instance.showInAppMessage();
  }

  Future<void> showCampaign() {
    return BuzzBoosterPlatform.instance.showCampaign();
  }

  Future<void> showPage(String pageId) {
    return BuzzBoosterPlatform.instance.showPage(pageId);
  }

  Future<void> setPushToken(String token) {
    return BuzzBoosterPlatform.instance.setPushToken(token);
  }

  Future<bool> isBuzzBoosterNotification(Map<String, dynamic> map) {
    return BuzzBoosterPlatform.instance.isBuzzBoosterNotification(map);
  }

  Future<void> handleNotification(Map<String, dynamic> map) {
    return BuzzBoosterPlatform.instance.handleNotification(map);
  }
  
  Future<void> showCampaignWithId(String campaignId) {
    return BuzzBoosterPlatform.instance.showCampaignWithId(campaignId);
  }

  Future<void> showSpecificCampaign(CampaignType campaignType) {
    return BuzzBoosterPlatform.instance.showSpecificCampaign(campaignType);
  }

  Future<void> handleInitialMessage(Map<String, dynamic> data) {
    return BuzzBoosterPlatform.instance.handleInitialMessage(data);
  }

  Future<void> handleOnMessageOpenedApp(Map<String, dynamic> data) {
    return BuzzBoosterPlatform.instance.handleOnMessageOpenedApp(data);
  }
  
  Future<void> postJavaScriptMessage(String message) {
    return BuzzBoosterPlatform.instance.postJavaScriptMessage(message);
  }
}

class UserBuilder {
  final String userId;
  bool? optInMarketing;
  Map<String,String> properties = {};
  
  UserBuilder(this.userId);

  UserBuilder setOptInMarketing(bool optInMarketing) {
    this.optInMarketing = optInMarketing;
    return this;
  }

  UserBuilder addProperty(String key, String value) {
    properties[key] = value;
    return this;
  }

  User build() {
    return User._builder(this);
  }
}

class User {
  final String userId;
  final bool? optInMarketing;
  final Map<String,String> properties;

  User._builder(UserBuilder builder) :
    userId = builder.userId,
    optInMarketing = builder.optInMarketing,
    properties = builder.properties;
}

enum CampaignType {
  attendance,
  referral,
  optInMarketing
}

==> 3.0.0.tar.gz: lib/buzz_booster.dart <==
import 'package:buzz_booster/buzz_booster_method_channel.dart';
import 'buzz_booster_platform_interface.dart';

class BuzzBooster {
  Function()? _optInMarketingCampaignMoveButtonClickedCallback = null;
  set optInMarketingCampaignMoveButtonClickedCallback(Function()? callback){
    _optInMarketingCampaignMoveButtonClickedCallback = callback;
  }

  Function(String, Map<String, dynamic>?)? _userEventChannel = null;
  set userEventChannel(Function(String, Map<String, dynamic>?)? userEventChannel){
    _userEventChannel = userEventChannel;
  }

  BuzzBooster() {
    BuzzBoosterPlatform.instance.eventStream.listen((event) {
      if (event.key == NativeEvent.optInMarketingCampaignMoveButtonClicked) {
        _optInMarketingCampaignMoveButtonClickedCallback?.call();
      } else if (event.key == NativeEvent.userEventDidOccur) {
        _userEventChannel?.call(event.value["userEventName"], event.value["userEventValues"]);
      }
    });
  }

  Future<void> setUser(User? user, ) {
    return BuzzBoosterPlatform.instance.setUser(user, );
  }

  Future<void> init(
      {required String androidAppKey, required String iosAppKey}) {
    return BuzzBoosterPlatform.instance
        .init(androidAppKey: androidAppKey, iosAppKey: iosAppKey);
  }

  Future<void> sendEvent(
    String eventName,
    Map<String, Object>? eventValues,
  ) {
    eventValues?.forEach((key, value) {
      assert(
        value is String || value is num || value is bool,
        "'string' OR 'number' OR 'bool' must be set as the value of the parameter: $key",
      );
    });
    return BuzzBoosterPlatform.instance.sendEvent(
      eventName,
      eventValues,
    );
  }

  Future<void> showInAppMessage() {
    return BuzzBoosterPlatform.instance.showInAppMessage();
  }

  Future<void> showHome() {
    return BuzzBoosterPlatform.instance.showHome();
  }

  Future<void> showPage(String pageId) {
    return BuzzBoosterPlatform.instance.showPage(pageId);
  }

  Future<void> setPushToken(String token) {
    return BuzzBoosterPlatform.instance.setPushToken(token);
  }

  Future<bool> isBuzzBoosterNotification(Map<String, dynamic> map) {
    return BuzzBoosterPlatform.instance.isBuzzBoosterNotification(map);
  }

  Future<void> handleNotification(Map<String, dynamic> map) {
    return BuzzBoosterPlatform.instance.handleNotification(map);
  }
  
  Future<void> showCampaignWithId(String campaignId) {
    return BuzzBoosterPlatform.instance.showCampaignWithId(campaignId);
  }

  Future<void> showCampaignWithType(CampaignType campaignType) {
    return BuzzBoosterPlatform.instance.showCampaignWithType(campaignType);
  }

  Future<void> handleInitialMessage(Map<String, dynamic> data) {
    return BuzzBoosterPlatform.instance.handleInitialMessage(data);
  }

  Future<void> handleOnMessageOpenedApp(Map<String, dynamic> data) {
    return BuzzBoosterPlatform.instance.handleOnMessageOpenedApp(data);
  }
  
  Future<void> postJavaScriptMessage(String message) {
    return BuzzBoosterPlatform.instance.postJavaScriptMessage(message);
  }
}

class UserBuilder {
  final String userId;
  bool? optInMarketing;
  Map<String, Object> properties = {};
  
  UserBuilder(this.userId);

  UserBuilder setOptInMarketing(bool optInMarketing) {
    this.optInMarketing = optInMarketing;
    return this;
  }

  UserBuilder addProperty(String key, Object value) {
    assert(
      value is String || value is num || value is bool,
      "'string' OR 'number' OR 'bool' must be set as the value of the parameter: $key",
    );
    properties[key] = value;
    return this;
  }

  User build() {
    return User._builder(this);
  }
}

class User {
  final String userId;
  final bool? optInMarketing;
  final Map<String, Object> properties;

  User._builder(UserBuilder builder) :
    userId = builder.userId,
    optInMarketing = builder.optInMarketing,
    properties = builder.properties;
}

enum CampaignType {
  attendance,
  referral,
  optInMarketing,
  scratchLottery,
  roulette
}
